from rq_interfaces.msg import Projection
from rq_interfaces.srv import AquireProjection

from rq_controller.common import PyProjection

import rclpy
from rclpy.node import Node

class HardwareClient(Node):

    def __init__(self):
        super().__init__('rq_hardware_client')
        self.cli = self.create_client(AquireProjection, 'aquire_projection')
        while not self.cli.wait_for_service(timeout_sec=1.0):
            self.get_logger().info('service not available, waiting again...')
        self.req = AquireProjection.Request()

    def aquire_projection(self, projection: PyProjection) -> rclpy.Future:
        self.req.scan_pose = projection.as_message()

        return self.cli.call_async(self.req)
    
    @staticmethod
    def response_2_py(response: AquireProjection.Response) -> PyProjection:
        return PyProjection.from_message(response.projection)


def main():
    from matplotlib import pyplot as plt

    rclpy.init()

    minimal_client = HardwareClient()
    scan_pose = PyProjection.dummy()

    future = minimal_client.aquire_projection(scan_pose)
    rclpy.spin_until_future_complete(minimal_client, future)

    response = future.result()
    projection = minimal_client.response_2_py(response)
    minimal_client.get_logger().info(
        f'Received Projection ...')

    minimal_client.destroy_node()
    rclpy.shutdown()


    plt.imshow(projection.image)
    plt.show()

    


if __name__ == '__main__':
    main()